=====
GS123
=====


.. image:: https://gitlab.com/serial-lab/gs123/badges/master/pipeline.svg
        :target: https://gitlab.com/serial-lab/gs123/commits/master

.. image:: https://gitlab.com/serial-lab/gs123/badges/master/coverage.svg
        :target: https://gitlab.com/serial-lab/gs123/pipelines

.. image:: https://badge.fury.io/py/gs123.svg
    :target: https://badge.fury.io/py/gs123



Set of python tools to convert various GS1 formats to and from others.
GS123 is an essential component of the QU4RTET Open Source EPCIS and is
used in various tasks throughout the platform.  GS123 can also be used
as a standalone component to convert barcode data to URNs, etc.

Documentation
-------------

Find the latest docs here:

https://serial-lab.gitlab.io/gs123/

Features
--------

* Converts GS1 barcode values to EPC URN values.
* Check digit calculation.
* Converts URN values to barcode values.
* Regular expressions to select barcode values in files.
* File conversion utilities.
